import { Node, SourceFileNode, ContractNode, ParameterNode, VariableDefinitionNode, FunctionDefinitionNode, AssignNode, IdentifierNode, BranchNode, CastNode, FunctionCallNode, UnaryOpNode, BinaryOpNode, BoolLiteralNode, IntLiteralNode, HexLiteralNode, StringLiteralNode, BlockNode, TimeOpNode, ArrayNode, TupleIndexOpNode, RequireNode, InstantiationNode, TupleAssignmentNode, NullaryOpNode } from './AST.js';
export default abstract class AstVisitor<T> {
    abstract visitSourceFile(node: SourceFileNode): T;
    abstract visitContract(node: ContractNode): T;
    abstract visitFunctionDefinition(node: FunctionDefinitionNode): T;
    abstract visitParameter(node: ParameterNode): T;
    abstract visitVariableDefinition(node: VariableDefinitionNode): T;
    abstract visitTupleAssignment(node: TupleAssignmentNode): T;
    abstract visitAssign(node: AssignNode): T;
    abstract visitTimeOp(node: TimeOpNode): T;
    abstract visitRequire(node: RequireNode): T;
    abstract visitBranch(node: BranchNode): T;
    abstract visitBlock(node: BlockNode): T;
    abstract visitCast(node: CastNode): T;
    abstract visitFunctionCall(node: FunctionCallNode): T;
    abstract visitInstantiation(node: InstantiationNode): T;
    abstract visitTupleIndexOp(node: TupleIndexOpNode): T;
    abstract visitBinaryOp(node: BinaryOpNode): T;
    abstract visitUnaryOp(node: UnaryOpNode): T;
    abstract visitNullaryOp(node: NullaryOpNode): T;
    abstract visitArray(node: ArrayNode): T;
    abstract visitIdentifier(node: IdentifierNode): T;
    abstract visitBoolLiteral(node: BoolLiteralNode): T;
    abstract visitIntLiteral(node: IntLiteralNode): T;
    abstract visitStringLiteral(node: StringLiteralNode): T;
    abstract visitHexLiteral(node: HexLiteralNode): T;
    visit(node: Node): T;
    visitOptional(node?: Node): T | undefined;
    visitList(nodes: Node[]): T[];
    visitOptionalList(nodes?: Node[]): T[] | undefined;
}
