import { ParseError } from '../Errors.js';
import { Point } from './Location.js';
/**
 * ANTLR Error Listener that immediately throws on error. This is used so that
 * ANTLR doesn't attempt any error recovery during lexing/parsing and fails early.
 */
export default class ThrowingErrorListener {
    syntaxError(recognizer, offendingSymbol, line, charPositionInLine, message, e) {
        const capitalisedMessage = message.charAt(0).toUpperCase() + message.slice(1);
        throw new ParseError(capitalisedMessage, new Point(line, charPositionInLine));
    }
}
ThrowingErrorListener.INSTANCE = new ThrowingErrorListener();
//# sourceMappingURL=ThrowingErrorListener.js.map